package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````("%```````!``````````'"C````
M`````````$``.``+`$``'P`>``8````$````0`````````!``$```````$``
M0```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"0```````J`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````)B;````````F)L`````````
M$`````````$````&````D)T```````"0K4```````)"M0```````>`0`````
M``#X!``````````0`````````@````8```"XG0```````+BM0```````N*U`
M```````@`@```````"`"````````"``````````$````!````,@"````````
MR`)```````#(`D```````"``````````(``````````(``````````0````$
M````Z`(```````#H`D```````.@"0```````1`````````!$``````````0`
M````````4^5T9`0```#(`@```````,@"0```````R`)````````@````````
M`"``````````"`````````!0Y71D!````(R4````````C)1```````",E$``
M``````0!````````!`$````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"0G0```````)"M0```````D*U```````!P`@```````'`"`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(```````0````0````
M!0```$=.50`"@`#`!`````$`````````!````!`````!````1TY5```````$
M`````P`````````$````%`````,```!'3E4`T/:>;>\#W3OVSPW.M?#@AF?J
MP10`````0P```%T``````````````%0````A````(@````8`````````20``
M```````X````4````#$````?````4P```$X````J````-```````````````
M6P``````````````'0```"````!&`````````$H````4````-@```$<`````
M`````````%8`````````.0```#,``````````````$4````I`````````#4`
M````````+````%D````6````&P```%<`````````00```$@````#````````
M`%@````R````!0```#<`````````0````%$```!-````3P````P````[````
M)P```"8````]`````````%4`````````````````````````````````````
M``````````@````^``````````````````````````<```!#``````````T`
M``!:````$P```````````````````!@```````````````````!"````````
M`````````````````!X```!2````$@````0`````````)0````````!$````
M*`````X````9````'````!4````D````2P````L````:````$````"L````Z
M````/``````````O````3`````D`````````(P```%P``````````````#``
M``````````````$``````````````!$``````````````"T````/````%P``
M`#\``````````````"X`````````"@``````````````````````````````
M```````````````````````````"````$0```#H````$````"````"`<$``%
M0`2&*`)`!)"&`8S""0`@22`$"KB",$FZ``8*.@```#L````^````00```$(`
M``!*````3````$X```!2````4P```%0```!5````6````%D```!;````````
M``````![\$IK;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP$+ZUX?"Y3\LNN.2?/+;TQW[H6Q@:@E#UH?YG(%FK\QFQ;F<0#CRBQS$
MB0600D75[(D'<-/)U;)Q,V+;[16,)<P,.I<+5J2;EJ?=HVM_J9R;X*<""FL:
MGE`*BA!7H^#[20```````````````````````````````,H!```2````````
M`````````````````*8````2`````````````````````````$T````2````
M`````````````````````!\!```2`````````````````````````-X!```2
M`````````````````````````)@!```2``````````````````````````$`
M```@`````````````````````````&@"```2````````````````````````
M`)X"```2`````````````````````````%<!```2````````````````````
M`````,(!```2`````````````````````````#8!```2````````````````
M`````````.T````2`````````````````````````-T````2````````````
M`````````````+0!```2`````````````````````````/4!```2````````
M`````````````````,\````2`````````````````````````&,!```2````
M`````````````````````%T#```2`````````````````````````#T!```2
M`````````````````````````*L````2`````````````````````````/L!
M```2`````````````````````````$`"```2````````````````````````
M`$<"```2`````````````````````````!`````2````````````````````
M`````(H````2`````````````````````````#X````2````````````````
M`````````#<"```2`````````````````````````*T!```2````````````
M`````````````.X!```2`````````````````````````&X````2````````
M`````````````````&T"```2`````````````````````````&H!```2````
M`````````````````````%P!```2``````````````````````````$!```2
M`````````````````````````%<"```2``````````````````````````("
M```2`````````````````````````+`````2````````````````````````
M`'8"```2`````````````````````````*8!```2````````````````````
M`````+L!```2`````````````````````````#\"```2````````````````
M`````````-<!```2`````````````````````````'(!```2````````````
M`````````````%D````2`````````````````````````"H!```2````````
M`````````````````$\"```2`````````````````````````.4!```2````
M`````````````````````!L"```2`````````````````````````(<"```2
M``````````````````````````D"```2`````````````````````````/8`
M```2`````````````````````````!X````2````````````````````````
M`(8!```2`````````````````````````#`"```2````````````````````
M`````!$"```2`````````````````````````(X"```2````````````````
M``````````\!```2````$!U``````````````````&8#```2``\`\#A`````
M``!>`````````+L#```2``\`\"]```````"<!@```````),!```2``\`(!]`
M``````#W`0```````-T"```2``\``"M````````%`````````/L"```2``\`
MD#9```````!6`@```````.$#```2``\`$"M```````#_`0```````*$#```0
M`!P`(+)``````````````````.X"```2``\`$"U````````B`````````!$#
M```2``\`T"Y````````X`````````'(#```1`!$`>%-````````$````````
M`(X#```2``\`@$]```````"2`0```````)D#```2``\`P"E````````J````
M`````+8#```0`!P`B+)``````````````````$@!```1`!8`H*U````````3
M`````````,\#```2``\`0"]```````"M`````````($#```0`!H`T+%`````
M`````````````"T````2````(!U``````````````````#4#```2``\`0"U`
M``````!$`````````)0"```1`!P`*+)````````(`````````"D"```1`!P`
M0+)````````(`````````)4"```A`!P`*+)````````(`````````,@#```0
M`!L`"+)``````````````````.X#```1`!H`\+%````````(`````````+P`
M```2````X!M``````````````````(<#```2``\`("%````````B````````
M`*T#```2``\`($]```````!4`````````(,#```@`!H`T+%`````````````
M`````)L````1`!P`(+)````````$`````````)8"```A`!P`*+)````````(
M`````````$L#```2``\`$"]````````D`````````!\#```2``\`0"I`````
M``"Y`````````$$#```2``\`(%%````````C`@```````'T````1`!P`8+)`
M```````!`````````/@#```2``\`D"U````````W`0````````!?7V=M;VY?
M<W1A<G1?7P!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F
M;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A
M:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!03%]M96UO<GE?=W)A<`!R96%D`'-T<F-H<@!G971P:60`;65M;6]V
M90!P=&AR96%D7V=E='-P96-I9FEC`%]?;&EB8U]S=&%R=%]M86EN`%]?9G!R
M:6YT9E]C:&L`<W1R8VUP`&]P96XV-`!U;FQI;FL`<W1R=&]K`'-T<FYC;7``
M7U]S='!C<'E?8VAK`&=E='5I9`!M96UC:'(`8VQO<V5D:7(`<W1R<W1R`')M
M9&ER`'-T<FQE;@!S=')D=7``<F5A;&QO8P!R96%D9&ER-C0`7U]S<')I;G1F
M7V-H:P!S=&1E<G(`;65M8W!Y`'-T<G)C:'(`;'-T870V-`!O<&5N9&ER`&QS
M965K-C0`7U]E<G)N;U]L;V-A=&EO;@!E>&ET`')E861L:6YK`%]?<W1A8VM?
M8VAK7V9A:6P`86-C97-S`&UK9&ER`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T
M9F]R:P!L:6)P97)L+G-O`&QI8FTN<V\N-@!L:6)C<GEP="YS;RXQ`&QI8F,N
M<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R
M=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N
M9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F
M:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`$=,24)#7S(N,30`1TQ)
M0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"
M0U\R+C(N-0!'3$E"0U\R+C,N-``O=7-R+VQI8B]P97)L-2\U+C(V+C$O>#@V
M7S8T+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%``````(``0`!``$``P`"``$`
M`P`$``,``P`#``$``0`#``,``0`#``,``0`#``,`!0`#``$``0`!``,``P`#
M``$``P`#``,``0`#``,``0`&``,``P`%``,`!P`!``$``P`#``(``P`#``$`
M`0`'``@``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``P`#``,``0`!``$``0`!``$``0`#``$``0`!``$``0```````0`'`-,"
M```0`````````)21E@8```@`!00``!````"TD98&```'`!`$```0````%&EI
M#0``!@`;!```$````+.1E@8```4`)00``!````!R&6D)```$`#`$```0````
M=1II"0```P`\!```$````'09:0D```(`2`0```````#8KT````````8````'
M``````````````#@KT````````8````V``````````````"@K4````````4`
M``!(```````````````@LD````````4```!6```````````````HLD``````
M``4```!-``````````````!`LD````````4```!.``````````````!@LD``
M``````4```!;````````````````L$````````<````!```````````````(
ML$````````<````"```````````````0L$````````<````#````````````
M```8L$````````<````$```````````````@L$````````<````%````````
M```````HL$````````<````&```````````````PL$````````<```!2````
M```````````XL$````````<````(``````````````!`L$````````<````)
M``````````````!(L$````````<````*``````````````!0L$````````<`
M```+``````````````!8L$````````<````,``````````````!@L$``````
M``<````-``````````````!HL$````````<````.``````````````!PL$``
M``````<````/``````````````!XL$````````<````0``````````````"`
ML$````````<````1``````````````"(L$````````<````2````````````
M``"0L$````````<````3``````````````"8L$````````<````4````````
M``````"@L$````````<````5``````````````"HL$````````<````6````
M``````````"PL$````````<````7``````````````"XL$````````<````8
M``````````````#`L$````````<````9``````````````#(L$````````<`
M```Z``````````````#0L$````````<```!+``````````````#8L$``````
M``<````:``````````````#@L$````````<````;``````````````#HL$``
M``````<````<``````````````#PL$````````<````=``````````````#X
ML$````````<````>````````````````L4````````<````?````````````
M```(L4````````<````@```````````````0L4````````<````A````````
M```````8L4````````<````B```````````````@L4````````<````C````
M```````````HL4````````<````D```````````````PL4````````<````E
M```````````````XL4````````<````F``````````````!`L4````````<`
M```G``````````````!(L4````````<````H``````````````!0L4``````
M``<````I``````````````!8L4````````<````J``````````````!@L4``
M``````<````K``````````````!HL4````````<````L``````````````!P
ML4````````<````M``````````````!XL4````````<````N````````````
M``"`L4````````<````O``````````````"(L4````````<````P````````
M``````"0L4````````<````Q``````````````"8L4````````<````R````
M``````````"@L4````````<````S``````````````"HL4````````<````T
M``````````````"PL4````````<````U``````````````"XL4````````<`
M```W``````````````#`L4````````<````X``````````````#(L4``````
M``<````Y``````````````!(@^P(2(L%?90``$B%P'0"_]!(@\0(PP``````
M`````/\U>I0``/\E?)0```\?0`#_)7J4``!H`````.G@_____R5RE```:`$`
M``#IT/____\E:I0``&@"````Z<#_____)6*4``!H`P```.FP_____R5:E```
M:`0```#IH/____\E4I0``&@%````Z9#_____)4J4``!H!@```.F`_____R5"
ME```:`<```#I</____\E.I0``&@(````Z6#_____)3*4``!H"0```.E0____
M_R4JE```:`H```#I0/____\E(I0``&@+````Z3#_____)1J4``!H#````.D@
M_____R42E```:`T```#I$/____\E"I0``&@.````Z0#_____)0*4``!H#P``
M`.GP_O___R7ZDP``:!````#IX/[___\E\I,``&@1````Z=#^____)>J3``!H
M$@```.G`_O___R7BDP``:!,```#IL/[___\EVI,``&@4````Z:#^____)=*3
M``!H%0```.F0_O___R7*DP``:!8```#I@/[___\EPI,``&@7````Z7#^____
M);J3``!H&````.E@_O___R6RDP``:!D```#I4/[___\EJI,``&@:````Z4#^
M____):*3``!H&P```.DP_O___R6:DP``:!P```#I(/[___\EDI,``&@=````
MZ1#^____)8J3``!H'@```.D`_O___R6"DP``:!\```#I\/W___\E>I,``&@@
M````Z>#]____)7*3``!H(0```.G0_?___R5JDP``:"(```#IP/W___\E8I,`
M`&@C````Z;#]____)5J3``!H)````.F@_?___R52DP``:"4```#ID/W___\E
M2I,``&@F````Z8#]____)4*3``!H)P```.EP_?___R4ZDP``:"@```#I8/W_
M__\E,I,``&@I````Z5#]____)2J3``!H*@```.E`_?___R4BDP``:"L```#I
M,/W___\E&I,``&@L````Z2#]____)1*3``!H+0```.D0_?___R4*DP``:"X`
M``#I`/W___\E`I,``&@O````Z?#\____)?J2``!H,````.G@_/___R7RD@``
M:#$```#IT/S___\EZI(``&@R````Z<#\____)>*2``!H,P```.FP_/___R7:
MD@``:#0```#IH/S___\ETI(``&@U````Z9#\____)<J2``!H-@```.F`_/__
M_R7"D@``:#<```#I</S___\ENI(``&@X````Z6#\____);*2``!H.0```.E0
M_/__4TB#[#")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(C50D".B9____NN`;
M0`"_(!U``$B)UN@%-```@#T`DP```'4OZ$G]__](A<!(B04/DP``#X26`0``
M2(G'Z,']__^+/9N2``#HQO[__\:`T0@```"+/8F2``#HM/[__X"(J@0```*+
M/7>2``#HHO[__X"(J@0```&+1"0<C7@$C5@#2+C_________'TAC_T@YQP^'
M!P$``$C!YP/HDO[__TB+?"001(M$)!Q(B06)D@``2(L708/X`4C'0`@\54``
M2,=`&#]50`!(B1!(BQ7@D0``2(E0$`^.N````$B#QPA!@\`#O@0```!F#Q^$
M``````!(BP](8]:#Q@%(@\<(1#G&2(D,T'7J2&/V2,'F`TB+/2R2``!(QP0P
M`````$4QP(G:2(G!OO`I0`#H0OO__X7`B<-T3DB+/062``#H0/W__TB-="0L
M,<"_'%1``.B/`0``2(7`=!E(BSWCD0``Z.[Z___H6?S__TB#Q#")V%O#2(L]
MNI$``$B%_W0RZ#`8``#KU$B+/;>1``#H<OO__XG#ZZ*^(````.EQ____OJ"M
M0`"_SE-``#'`Z'/]__](C70D++_14T``Z"0!``!(A<!(B<=(B05GD0``=(OK
MKK\!````Z-GZ__]F#Q^$```````Q[4F)T5Y(B>)(@^3P4%1%,<`QR4C'QR`?
M0`#_%9^.``#T9BX/'X0```````\?0`"0D)"0D)"0D)"0D)"0D)"0PV8N#Q^$
M```````/'T0``%6X"+)``$@]"+)``$B)Y707N`````!(A<!T#5V_"+)``/_@
M#Q]$``!=PV8/'T0``+X(LD``54B![@BR0`!(B>5(P?X#2(GP2,'H/T@!QDC1
M_G05N`````!(A<!T"UV_"+)``/_@#Q\`7<-F#Q]$``"`/7J0````=1=52(GE
MZ'[____&!6B0```!7<,/'T0``//#9F8N#Q^$```````/'P!52(GE7>N)9@\?
MA```````05=!5D%505154TB#[`A(A?\/A+$```!,BSWJCP``387_#X2A````
M#[8'A,!T!#P]=5Y%,>1)BQ](A=MT.4F)]4F)_DUCY$R)_0\?@`````!,B>),
MB?9(B=_HHOG__X7`=0="@#PC/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<
M05U!7D%?PP\?A```````28G\28/$`4$/M@0DA,!T!#P]=>]!*?SKC`\?@```
M``!,*?U*C5PC`4C!_0-!B6T`Z[1F#Q]$```QV^NJ#Q]``%-(B?M(@^P0#Q^$
M``````!(C70D##'`2(G?Z!'___](A<!T-$AC5"0,2(L%"(\``$B-!-!(BU`(
M2(722(D0=-!(@\`(2(M0"$B%TDB)$'7PZ[YF#Q]$``!(@\006\-FD$%7058Q
MP$%505154TB)\TB)_4B#["B`/CT/E,!(`<-(B=_H6?G__TB-="0<28G$2(GO
M,<#HE_[__TB%P`^$_@```$B)QTF)Q>@S^?__3#G@#X/2````3&-T)!Q)P>8#
M#[9%`(3`#X2=`0``/#T/A)4!``!(B>CK#0\?A```````@/H]=`M(@\`!#[80
MA-)U\$@IZ$B83`,U/(X``$J-?"`"Z#KX__](A<!)B08/A&L!``!(8U0D'$B+
M!1J.``!(C4T!2(L4T`^V10`\/8@"=":$P'40ZR!F+@\?A```````/#UT$DB#
MP0$/MD'_2(/"`83`B`)UZL8"/3'`#Q]$```/M@P#B$P"`4B#P`&$R77P,<!(
M@\0H6UU!7$%=05Y!7\,/'X``````2(/#`0^V0_])@\4!A,!!B$7_=>SKTF:0
M3(L]D8T``$F#/P`/A+\```!,B?@QTNL+#Q^$``````!$B>I(@\`(1(UJ`4B#
M.`!U[XUR`TAC]DC!Y@.+!9>-``"%P'5;2(GWQP6&C0```0```.A)]___2(7`
M#X1]````36/%3(G^2(G'3HTTQ0````!,B40D"$R)\NB2^/__3(M$)`A(B<%(
MB04+C0``2L=$P0@`````1(EL)!SI?_[__TR)_^B(^?__2(7`2(G!2(D%XXP`
M`'0F36/%3HTTQ0````#KR0\?0``QP.F&_O__D+X0````13'MZ5[___^X____
M_^GK_O__9@\?A```````2(7_=`6`/P!U!O/##Q]``$%505154TB)^TB![)@`
M``#H2_?__TB%P$F)Q`^$SP```$R)Y^A'^?__2(7`#X2N````2(UH$[]]4T``
MN0(```!(B>[SI@^7P!P`A,!TT[]\4T``N0,```!(B>[SI@^7P!P`A,!TNTB)
MW^C2]O__2(GO28G%Z,?V__]!C7P%`DAC_^@:]O__28GI28G%2(G'28G8N7]3
M0`!(Q\+_____O@$````QP.AF^/__3(GO2(GFZ)OV__^#^/],B>]T$(M$)!@E
M`/```#T`0```=#'H_O7__TR)[^A6]O__Z4+___^03(GGZ!CX__](B=_H\/7_
M_TB!Q)@```!;74%<05W#Z.W^___KS69F+@\?A```````4TB)^TB![)````!(
MB>;H???__X7`=2F+5"08@>(`\```@?H`0```=">!^@"@``!T'TB!Q)````!;
MPV8/'T0``$B!Q)`````QP%O##Q]$``!(B=^^`@```.BS]___A<`/E,!(@<20
M````#[;`6\-FD$%5051)B?554TB)_;K_#P``OX530`!(@>P8$```2(GF9$B+
M!"4H````2(F$)`@0```QP.A(]O__A<`/CI````"-4/]$BR7&B@``2&/:@#P<
M`'152&/82(G:OB\```!(B>?H2O3__TB%P'1%1(GGZ,WV__](B=E(B>)(B>Y(
MB<?H[/7__TB+A"0($```9$@S!"4H````=4)(@<08$```6UU!7$%=PP\?`(72
M=:H/'T``1(GGZ(CV__],B>I(B>Y(B<?HJO3__^N\#Q^$``````!$BR4YB@``
MZ]?H$O;__V:04TB)_KH`$```2('L$!```$B)XTB)WV1(BP0E*````$B)A"0(
M$```,<#H8O/__TB#Z`%(.=AW%>L8#Q^``````,8``$B#Z`%(.=AT!8`X+W3O
MOB\```!(B=_H`O7__TB%P'0U2#G8=RA(B=_H@/7__TB+C"0($```9$@S#"4H
M````=3I(@<00$```6\,/'T``Q@``Z],/'P!(BX0D"!```&1(,P0E*````'42
M2('$$!```+]]4T``6^DS]?__Z$[U__]F9BX/'X0```````\?`$%45;H"````
M4S'V08G\2('L$``!`&1(BP0E*````$B)A"0(``$`,<#HD_7__TB-:/](B>I(
MP?H_2,'J,$B-1!4`#[?`2"G02"G%#XB4````2(GC#Q]$```QTDB)[D2)Y^A;
M]?__N@@``0!(B=Y$B>?HV_+__TB82(/X!W932(U$`_A(.=AS$NM'#Q^`````
M`$B#Z`%(.=AR-TB+#8"(``!(.0AUZT@IW4@!Z$B+M"0(``$`9$@S-"4H````
M=2](@<00``$`6UU!7,-F#Q]$``!(@>T```$`2(']``#__P^%=/___TC'P/__
M___KONA.]/__9F8N#Q^$```````/'P!(@^P(BSU6B```Z('T__^Y@)1``+H0
M'4``OI130`!(B<=(@\0(Z>;T__]F#Q]$``!(@^P(BSTFB```Z%'T__](B<?H
MN?___XL]$X@``.@^]/__0;@954``13')NI`V0`!,B<&^L%-``$B)QTB#Q`CI
M_/+__V9F+@\?A```````D%-(@>P@(```9$B+!"4H````2(F$)!@@```QP.@P
M\O__0;F04T``08G`N<530`"Z`1```+X!````2(GG,<#H'O3__TB-M"00$```
MN@`0``!(B>?H^?+__X7`>%6->`%(B<-(8__HA_'__TB%P$B)P70=2&/;2(VT
M)!`0``!(B<=(B=KH*?3__TB)P<8$&`!(BY0D&"```&1(,Q0E*````$B)R'40
M2('$("```%O##Q\`,<GKVN@'\___#Q^``````.D[____9F8N#Q^$``````!!
M54%455-(B?U(B?._T5-``$B![*@0``!D2(L$)2@```!(B80DF!```#'`2(GF
MZ-WV__^^+P```$B)[TF)Q>A=\O__2(7`=#A(B>Z_VE-``#'`Z.GW__](B>A(
MBXPDF!```&1(,PPE*`````^%B0$``$B!Q*@0``!;74%<05W#D$B)W^A(\O__
MON=30`!(B<?H>_+__TB%P$B)PW2K@#L`#X3L````9BX/'X0``````$V%[703
M2(G>3(GOZ$#R__^%P`^$J0```$B)W^CP\/__2(U4`_])B<1(.=-S)X`Z+W0+
MZR`/'T``@#HO=0S&`@!(@^H!2#G3=>](B=_HO_#__TF)Q$B)[^BT\/__28U$
M!`%(/?\/```/ARO___](@^P(N=140`"Z`!```%5!N>E30`!)B=B^`0```#'`
M2(V\)*````#H1_+__TB-="002(V\)*````#H=?#__X7`6EEU$(M$)!@E`/``
M`#T`@```=$\Q_[[G4T``Z)/Q__](A<!(B<,/A+_^__^`.P`/A1[___]-A>UT
M&;D"````OWU30`!,B>[SI@^7P!P`A,!TPI!!O`$```"[?5-``.E$____2(V\
M))````"^`0```.C.\?__A<!UFTB-M"20````O]I30`#H6/;__TB-O"20````
MZ-OP___I8/[__^CQ\/__D%.^+P```$B)^^@R\/__2(U0`4B%P$@/1=I(B=];
MZ:[P__]F9BX/'X0```````\?`$B%_W0K@#\`="932(G[Z'WO__](@\`!2#T`
M$```=R%(B=];Z8CZ__\/'X0``````+]]4T``Z6;P__]F#Q]$```QP%O#9F8N
M#Q^$``````"02(/L&#'`O^M30`#H4/7__S'`O_130`#H1/7__S'`O_Q30`#H
M./7__S'`OP540`#H+/7__S'`OPQ40`#H(/7__S'`OQQ40`#H%/7__S'`O]%3
M0`#H"/7__S'`ORA40`#H_/3__S'`OS)40`#H\/3__S'`OSQ40`#HY/3__S'`
MO]I30`#HV/3__TB-="0,,<"_1E1``.CW\___2(7`=`](B<:_,E1``#'`Z!/U
M__](C70D##'`OU=40`#HTO/__TB%P'0/2(G&OVE40``QP.CN]/__2(UT)`PQ
MP+]T5$``Z*WS__](A<!T*$B)QK_14T``,<#HR?3__[Z55$``OPQ40``QP.BX
M]/__2(/$&,,/'P!(C70D##'`OX140`#H;_/__TB%P'312(G&ORA40``QP.B+
M]/__Z\!F#Q^$``````!(@^P8,<"_*%1``$B-="0,Z#OS__\QTDB%P'05#[8`
M/#`/E,*$P`^4P`G"@_(!#[;2B=!(@\08PP\?A```````2(/L".@G[___B<?H
M@.W__TB%P'0+2(L`2(/$",,/'P`QP.OT9F8N#Q^$``````"00515,<!32(G]
MOY=40`!(@^P02(UT)`SHQ/+__TB%P$B)[G1T@#@`2(G#=&Q(B<?H_.W__TB%
MP'5K2(GOZ$_M__](B=])B<3H1.W__TF-?`0"Z)KL__](@^P(2,?"_____TB)
MQU-)B<1!N>=30`!)B>BYU%1``+X!````,<#HWN[__TR)YK^75$``,<#H?_/_
M_UA:ZP\/'P"_EU1``#'`Z&SS__](@\006UU!7,,/'P!!5D%5051528G\4[_1
M4T``2('L4`$``&1(BP0E*````$B)A"1(`0``,<!(C;0D@````$C'1"00LU1`
M`$C'1"08?5-``$C'1"0@`````$C'1"10:51``$C'1"188E1``$C'1"1@N%1`
M`$C'1"1H?U1``$C'1"1PP%1``$C'1"1X`````$C'1"0PIU1``$C'1"0XQ%1`
M`$C'1"1``````.B-\?__2(7`=`F`.``/A4\"```QP.AH_O__2(7`2(G##X2,
M`@``2(G?Z!3L__](C7P``>AJZ___@#L`28G%=#I,B>U)Q\;_____#Q^$````
M``!$#[8#2(GO,<"YS51``$R)\KX!````2(/#`4B#Q0+HG>W__X`[`'782(U<
M)%B_:51``.L5#Q]``$B#PPA(BWOX2(7_#X1O`0``2(VT)(`````QP.CH\/__
M2(7`2(G%=-B`.`!TTTB)Q^A3]?__A<!TQTB)[^B'[/__2(7`2(G##X0S`0``
M#Q\`2(G:BPI(@\($C8'__O[^]]$AR"6`@("`=.F)P<'I$*F`@```#T3!2(U*
M`D@/1-&)P0#!3(GI2(/:`T@IVHLQ2(/!!(V&__[^_O?6(?`E@("`@'3IB<;!
M[A"I@(````]$QDB-<0)(#T3.B<9``,9(@]D#3"GIC:P*!`0``$AC[4B)[^A!
MZO__055HVU1``$F)V$B)QTF)QD&YZ5-``+G25$``2,?"_____[X!````,<#H
M@^S__TR)][[``0``Z.;L__^#^/]?05AU$NB9Z___1(L(08/Y$0^%'00``$B-
MM"2`````3(GWZ-SK__^%P(G#=1>+A"28````)0#P```]`$````^$/P$``$F+
M#"1(BSW$?P``38GPNHA50`"^`0```#'`,>WH/NG__^M\#Q]``#'M9@\?1```
M2&/%2(M<Q!!(A=MT.X`[`'0V2(G?@\4!Z./S__^%P'3?2(G?Z!?K__](A<!(
MB<,/A9/^__](8\5(BUS$$$B%VW7+9@\?1```,=OI>?[__Y!(B<=(B40D".A#
M_/__2(M$)`A(B<?HUNK__TB)Q0\?`$B+E"1(`0``9$@S%"4H````2(GH#X5=
M`P``2('$4`$``%M=05Q!74%>PV8/'T0``+^G5$``,>U(A?]T+0\?0`!(C;0D
M@````#'`@\4!Z+[N__](A<!T!8`X`'4D2&/%2(M\Q#!(A?]UU[\-````NZQ4
M0`#HJ.C__TF)Q>D^_?__2(G'Z$CJ__](A<!(B<,/A1#]___KQF8N#Q^$````
M``!$BZPDG````.B#ZO__03G%#X6K_O__BX0DF````"7_`0``/<`!```/A93^
M__](B>_H2^C__TB-M"2`````2(G%OZ)40``QP.@D[O__2(7`#X1+`0``28L\
M)$B)QNC_]O__2(7`28G%#X0S`0``3(GOZ*OH__^#^`-^/DACT+_@5$``N04`
M``!)C705_/.F#Y?"@-H`A-)U((/X!`^$SP$``(/H!$B808!\!?\O#X2^`0``
M9@\?1```,<#H8?K__X7`=14Q]DR)[^CCZ/__A<!!B<0/A=@```"^E51``+\H
M5$``,<#HM^[__^CRY___:!E50`!02,?"_____T&YZ5-``$V)\+GY5$``O@$`
M``!(B>\QP.C8Z?__2<?$_____UA:ZT8/'T0``.CSZ/__@S@1=4GHJ>?__X/#
M`4B#[`A!N>E30`!H&55``%--B?!0N0=50`!,B>*^`0```$B)[S'`Z(OI__](
M@\0@OL`!``!(B>_HZNG__X/X_W2M3(GWZ(WG__](B>Z_T5-``#'`Z`[N__](
MB>_H]OG__^G!_?__D$V++"3IQ/[__P\?@`````")Q^A9\___2(7`28G%#X@5
M____2(UP]C'21(GGZ/_H__](C;0D@````+H&````1(GGZ'KF__^+!=Q>```Y
MA"2`````#X7?_O__#[<%S%X``&8YA"2$````#X7*_O__2(V<)!`!``!)C77.
M,=)$B>?HK.C__[HH````2(G>1(GGZ"SF___&A"0X`0```&@954``N>I40`!3
MO@$```!!N>E30`!-B?!(Q\+_____2(GO,<#HBNC__UE>Z0[___\/'P!-BV0D
M"$V%Y`^$.O[__TR)Y^B:YO__2(/X`P^&*/[__TF-=`3\O^540`"Y!0```/.F
M#Y?`'`"$P$T/1.SI!_[__TF+#"1(BSW4>P``38GPNDA50`"^`0```#'`,>WH
M3N7__^F)_/__Z'3G__\/'T``55-(@^P8BSV$>P``Z*_G__^+/7E[``!(B</H
MH>?__P^VD[@```!(C70D#+\,5$``B)"Y````,<#H4^O__TB%P'0)@#@Q#X25
M`0``,<#HKO;__XL].'L``.ACY___N0,```"Z`0```+X854``2(G'Z$SE__](
MA<!(B<-T,TB+0!"+/0I[``!(BRCH,N?__[H:54``2(G'2(GNZ%+E__](BT,0
M2(L8]D,.0`^%<0$``(L]VWH``.@&Y___N0,```"Z`0```+X?54``2(G'Z._D
M__](A<!(B<-T/4B-="0,,<"_VE-``.BFZO__2(7`2(G%#X3Z````2(M#$(L]
MD'H``$B+&.BXYO__2(GJ2(G'2(G>Z-KD__^+/71Z``#HG^;__[H!````OB%5
M0`!(B<?HW>/__XL]5WH``$B)P^A_YO__2(G>NC950`!(B<?HG^3__XL].7H`
M`.ADYO__2(UT)`S&@+D`````O]%30``QP.@<ZO__2(7`2(G#2(D%7WH``'0M
MOL`!``!(B=_H\.;__XU0`8/Z`78)@_@1#X6:````2(/$&%M=PP\?A```````
M2(L],7H``.BD]___2(7`2(G#2(D%%WH``'6XO^!50``QP.CYY?__9@\?A```
M````@'@!``^$:/[__^E<_O__D$B+!?%Y``"+/9-Y``!(BRA(BT,02(L8Z+3E
M__](B>Y(B=_H:>[__^GZ_O__#Q]``(L]:GD``.B5Y?__2(G>2(G'Z"KE___I
M=/[__XG!2(L%I'D``$B)VK\(5D``2(LP,<#H>N7__V8N#Q^$``````!54TB)
M^TB#[`CH0O3__TB)Q^@*]/__2(G%,<#HP/7__X7`=")(A=MT'8`[`'08O]M4
M0`"Y!````$B)[O.F#Y?`'`"$P'0*2(/$"%M=PP\?`$B#Q`A(B=];7>DR[/__
M9I!!5T%63(U/.$%505154TB![!`"``!(C4PDB$R-D8````!)B<@/'T``08L!
M28LQ28/`$$F#P0@/R$B)\HG`2,'J($F)0/!(B?!(P>XX2,'H*"4`_P``2`GP
M2(G62,'B"$C!YAB!X@``_P")]D@)\$@)T$F)0/A-.<)UKDB-L0`"```/'X``
M````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@_TB)07A(.?%U
MU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)T`-$)(B-E#"9
M>8):2(G82(MT))!(,>A,(<A(,>A(C;0UF7F"6D2-+`),B<I,B<A(P>@"2,'B
M'D@)PDB)V$V)Z(G12<'H&T@QR$PAT$@QV$@!\$R)[DC!Y@5,"<9$C20&3(G6
M3(G02,'F'DC!Z`)("?!(BW0DF$V)XT@QPDG!ZQM!B<!,(>I(C;0SF7F"6D@Q
MRD@!\DR)YDC!Y@5,"=Y$C1P63(GN2(M4)*!)P>T"2,'F'DP)[D@Q\$B-E!&9
M>8):3(G93"'@08GV3#'`2,'I&T@!T$R)VDC!X@5("<I,B>%)P>P"1(TL`DC!
MX1Y(BU0DJ$P)X4B)\$@QR$R)[D&)S$PAV$F-E!"9>8):2,'N&TPQ\$@!T$R)
MZDC!X@5("?)$C00"3(G:2(M$)+!)P>L"2,'B'DP)VDR)QD@QT4F-A`:9>8):
M2,'N&TPAZ4&)TTPQX4@!P4R)P$C!X`5("?!$C30(3(GH2(M,)+A)P>T"2,'@
M'DP)Z$R)]D@QPDF-C`R9>8):08G%3"'"3#':2`'*3(GQ2,'A!4C![AM("?%,
MB<9)P>@"1(TD$4C!YAY(BU0DP$P)QD@Q\$R)X4&)\$PA\$F-E!.9>8):2,'I
M&TPQZ$@!T$R)XDC!X@5("<I,B?%)P>X"1(T<`DC!X1Y(BU0DR$P)\4B)\$@Q
MR$R)WD&)SDPAX$F-E!69>8):2,'N&TPQP$@!T$R)VDC!X@5("?)$C2P"3(GB
M2(M$)-!)P>P"2,'B'DP)XDR)[D@QT4F-A`"9>8):2,'N&TPAV4&)U$PQ\4@!
MP4R)Z$C!X`5("?!$C00(3(G82(M,)-A)P>L"2,'@'DP)V$R)QD@QPDF-C`Z9
M>8):2,'N&TPAZD&)PTPQXD@!RDR)P4C!X05("?%,B>Y)P>T"1(TT$4C!YAY(
MBU0DX$P)[D@Q\$R)\4&)]4PAP$F-E!29>8):2,'I&TPQV$@!T$R)\DC!X@5(
M"<I,B<%)P>@"1(TD`DC!X1Y(BU0DZ$P)P4B)\$@QR$R)YD&)R$F-E!.9>8):
M3"'P2,'N&TPQZ$@!T$R)XDC!X@5("?)$C1P"3(GR2(M$)/!(P>(>2<'N`DP)
M\DR)WD@QT4F-A`69>8):2,'N&TPAX4&)UDPQP4@!P4R)V$C!X`5("?!$C2P(
M3(G@2(M,)/A)P>P"2,'@'DP)X$R)[D@QPDF-C`B9>8):2,'N&TPAVD&)Q$PQ
M\D@!RDR)Z4C!X05("?%,B=Y)P>L"1(T$$4C!YAY(BQ0D3`G>2#'P3(G!08GS
M3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)$C30"2,'A
M'DB+5"0(3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(P>X;3#'82`'03(GR
M2,'B!4@)\D2-)`),B<)(BT0D$$G!Z`)(P>(>3`G"3(GF2#'128V$`YEY@EI(
MP>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+="081(T<"$R)\$G![@)(P>`>
M3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),,<)(`?),B=Y(P>8%3`GNB?9(
M`?),B>9)P>P"2,'F'D&)U4P)YDR+9"0@2#'P3"'83XV$()EY@EI(,<A-B>Q)
MP>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))P>`>08G$30G828GSB?9-
M,<-(`W0D,$0QVDR+7"0H2HV,&:'KV6Y-B>-)P>L;2`'13(GB2,'B!4P)VHG2
M2`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!),=5,`T0D.$0QZ$V)W4B-M`:A
MZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=))
M,?1$,>%-B>Q(`U0D0$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!
MZP)(P>$>18G$3`G928GSB?9),<M(`W0D2$0QV$V)XTB-E`*AZ]EN3(G@2<'K
M&TC!X`5,"=B)P$@!PDR)Z$G![0)(P>`>08G33`GH28G-B<E),<5(`TPD4$4Q
MZ$V)W4Z-A`:AZ]EN3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU
M30G@28G$B<!-,<1$,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`-$)%A,">*)
MTD@!T4R)VDG!ZP)(P>(>08G,3`G:38G#18G`23'33`-$)&!$,=Y-B>-(C;0P
MH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G2
M23'U2`-4)&A$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)
MP>P"2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@
M!4P)X(G`2`'"3(G82`-T)'!)P>L"2,'@'D&)U$P)V$F)RXG)23'#2`-,)'A%
M,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@'D&)
M\TT)Z$F)Q8G`33'%2`.$)(````!$,>I-B=U(C8P1H>O9;DR)VDG![1M(P>(%
M3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-M#"A
MZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$)(@```!,"=Y)
MB=-!B<1),?.)TD@#E"20````1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A!4P)
MV8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"28````1#'H38G=
M2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,">!)
MB<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)V$G!
MZP))P>`>08GT30G82`.,)*````!)B<--,<.)P$@#A"2H````1#':38GC2<'K
M&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%
MB<!),=5,`X0DL````$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)P$@!
M\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0DN````$0QX4V)[$V-A`BA
MZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9)
M,<M$,=A-B>-(`[0DP````$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P03(GH
M2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F
M!4P)[DR+K"3(````1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G02"'P
M32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!S$R)
MV4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)-````!)`<5,`>I-B>5)
M`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)T4TA
MQDPAX4P)\4R+M"38````20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$C30.
M3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"3@````20'$30'C
M38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$B=I,
M"=Y)(=5,(?9,">Y,BZPDZ````$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%30GH
M18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)/````!)
M`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)X4F)
M]$&)RTD)R$TAZ$TAW$T)X$R+I"3X````20'$3`'B38GT20'03(GR2<'L&TC!
MX@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,BZPD
M``$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(P>8>
M3`GV38G&B?%("?))(<Y,(>),"?),B[0D"`$``$D!QDT!\TV)[DP!VDV)ZTG!
MXP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N3`GF
M3(ND)!`!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)P>T"
M2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"08`0``20'%3`'I38GE20'+
M3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-(=Y-
M(>!-"?!,B[0D(`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT`DR)
MXDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)"@!``!)`<1,`>9-
MB?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ2`GR
M22'-3"'R3`GJ3(NL)#`!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)ZT6-
M+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"0X`0``20'&
M30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)B=1$
MB<9-"<-)(?1-(>M-">-,BZ0D0`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(P>$%
M3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL)$@!
M``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DV)
MV$P)\D&)UD@)T4TA\$PAX4P)P4R+A"10`0``20'`3`'&38GH2`'Q3(GN2<'H
M&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),(>%,(>I("<I(
MBXPD6`$``$@!P4D!RTR)P4@#A"1@`0``3`':38G#2,'A!4G!ZQM,"=F)R4P!
M\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=2`'P
M3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,,<$Q
MRDB+C"1H`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)V4C!
MX1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,)'`!``!(`?%)`<]*
MC0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;20G%2(N$)'@!
M``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(2(N,)(`!``")
MP$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$18GM13'>2<'L
M&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"2(`0``
M2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)P>@"
MB=)(P>$>20'52(N4))`!``!,"<%-B?A%B>Y%B?]),<A(`?)%,<-(`=!,B?).
MC0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)"<1(
MBX0DF`$``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;2`G03(GR2<'N
M`HG`2,'B'DD!Q4B+A"2@`0``3`GR18GO2`'P2`'(3(GA18GD2#'103'(3(GY
M20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$)*@!
M``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+C"2P
M`0``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@QP46)VT$QR$R)
MZ4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+E"2X
M`0``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,B>E)
MP>T"B=)(P>$>20'32(N4),`!``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!,=!,
MB>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)Q4D)
MQTB+A"3(`0``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,B>))
MP>P"B<!(P>(>20'#2(N$)-`!``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](,=&)
MTD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!B<A)
M"<5(BX0DV`$``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(P>`%3`G@B<!)
M`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"3@`0``20'V20'63(GJ18GM2#'",=%)
MC10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(2(N,
M).@!``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GIB<E)
M`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"3P`0``2`'Q2`'(3(G!18G`3#'A,<I(
MC0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)/@!``!(
M`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#2,'H
M`DG!XQY!`=!,B>I)"<-(BX0D``(``$C!XAY)P>T"00';20G51(GB3(E?$$@!
M\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I&T4!R$@)RDR)
M1P@!T$$!PD0#=R!,B1=,B7<@2('$$`(``%M=05Q!74%>05_#9F8N#Q^$````
M```/'T``2(/L"+^`````Z`+-__^ZB:O-[[G^W+J8OO#ATL-(QP`!(T5G2(E0
M"$B)2!!(QT`8=E0R$$B)<"!(QT`H`````$C'0#``````QT!X`````$B#Q`C#
M9F8N#Q^$``````"005=!5DACPD%5051)B<554TB)\TF)_$B#[`A(BW<H2(M7
M,$F-;"0XC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC?WB%_W180;]`````
M2(G>02G_13G]10]._4@![TUC]TR)\N@'S___08M$)'A$`?B#^$!!B40D>'05
M2(/$"%M=05Q!74%>05_#9@\?1```3(GG12G]3`'SZ#+I__]FD$&#_3]^54&#
M[4!%B>]!P>\&18G^28/&`4G!Y@9)`=Z0\P]O`TR)YTB#PT`/$44`\P]O0]`/
M$440\P]O0^`/$44@\P]O0_`/$44PZ.'H__],.?-US$'!YP9%*?U)8\5(@_@(
M<EQ(BQ-)B50D.$B+5`/X2(E4!?A(C54(2(/B^$@IU4@IZT@!Q4B#Y?A(@_T(
M<A=(@^7X,<!(BPP#2(D,`DB#P`A(.>AR[T6);"1X2(/$"%M=05Q!74%>05_#
M#Q]``*@$=1U(A<!TWP^V$Z@"08A4)#ATTP^W5`/^9HE4!?[KQXL308E4)#B+
M5`/\B50%_.NV9F8N#Q^$```````/'P!!5D%53(UV.$%454B)_5-,BV8H2(GS
M3(MN,$R)X$C!Z`.#X#^-2`%(F,9$!CB`2&/!3`'P@_DX#X^3`0``NC@````Q
M]BG*@_H(#X)9`0``B=%(QP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B
M^(/Z"'(2@^+X,<")QX/`"#G02(DT.7+S3(GH1(AK<T2(8W=(P>@82(G?B$-P
M3(GH2,'H$(A#<4R)Z$C!Z`B(0W),B>!(P>@8B$-T3(G@2,'H$(A#=4R)X$C!
MZ`B(0W;H7.?__TB+`TC!Z!B(10!(BP-(P>@0B$4!2(L#2,'H"(A%`DB+`XA%
M`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(2,'H"(A%!DB+0PB(10=(BT,0
M2,'H&(A%"$B+0Q!(P>@0B$4)2(M#$$C!Z`B(10I(BT,0B$4+2(M#&$C!Z!B(
M10Q(BT,82,'H$(A%#4B+0QA(P>@(B$4.2(M#&(A%#TB+0R!(P>@8B$402(M#
M($C!Z!"(11%(BT,@2,'H"(A%$DB+0R"(11-;74%<05U!7NG[R?__#Q\`]L($
M=6.%T@^$T_[___;"`L8```^$Q_[__S')9HE,$/[IN_[__P\?`+I`````*<IT
M#S')B<Z#P0$YT<8$,`!R\TB)W^A`YO__9@_OP`\10SA)QT8P`````$$/$480
M00\11B#I>?[__Y#'``````#'1!#\`````.EE_O__9BX/'X0```````\?`)"0
MD)"0D)"0D)"0D)"0D)!(BPUQ7@``Z93(__](@^P(2(/$",,````!``(`+BX`
M)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!
M3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!54T52`%-94U1%30`O=&UP`%1%
M35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E<R5S)7,`<&%R+0!P87)L`"YP
M87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE
M=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4W`"UE`"TM
M`````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("10
M2UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO
M?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T
M96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D
M97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H
M<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT
M(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I
M+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@
M)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z
M:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T
M(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP
M<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE
M7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@
M)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP
M0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A
M:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N
M($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```````!#04-(10``<&5R;'AS:2YC
M`````1L#.P`!```?````Y(;__UP!``"4BO__Q`4``)2,__\<`0``THS__T@!
M``"4C?__A`$``&2.___0`0``Q([___`!``#TD/__/`(``!22__]X`@``A)+_
M_ZP"``!DD___Z`(``#24__\8`P``-)7__U`#``!DE?__:`,``+25__^``P``
M=);__Z0#``"$EO__N`,``(28__\(!```M)C__R0$```$F?__2`0``$2:__]D
M!```A)K__WP$``"TFO__F`0``&2;___4!```!*+__V0%``!DI/__D`4``,2D
M___L!0``E+K__S@&``#TNO__4`8``)2\__^T!@``TK[___0&```4````````
M``%Z4@`!>!`!&PP'")`!!Q`0````'````'"+__\B`````````!0`````````
M`7I2``%X$`$;#`<(D`$``!`````<````@HO__P,`````````)````#````"`
MA?__L`,````.$$8.&$H/"W<(@``_&CLJ,R0B`````$@```!8````"(S__\P`
M````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!
M#BA"#B!"#AA"#A!"#@A)"P`<````I````(R,__]>`````$$.$(,"1PX@`E0.
M$$$."$@```#$````S(S__R<"````0@X0CP)"#AB.`T0.((T$0@XHC`5!#C"&
M!D$..(,'2@Y@`P`!"@XX00XP00XH0@X@0@X80@X00@X(2`LX````$`$``+".
M__\5`0```%(.$(T"0@X8C`-!#B"&!$$.*(,%2@[``0+G"@XH00X@00X80@X0
M0@X(00LP````3`$``)2/__]N`````$$.$(,"2@Z@`6T*#A!!#@A'"T<*#A!#
M#@A&"UD.$$0."```.````(`!``#0C___W@````!"#A"-`D(.&(P#1`X@A@1!
M#BB#!50.P"`"@0H.*$$.($$.&$(.$$(."$0++````+P!``!TD/__P@````!!
M#A"#`D\.H"`">@H.$$$."$4+8@H.$$8."$4+````-````.P!```4D?__\@``
M``!"#A",`D$.&(8#1@X@@P1,#K"`!`*P"@X@00X800X00@X(1PL````4````
M)`(``-R1__\J`````$0.$&$."``4````/`(``/21__]$`````$0.$'L."``@
M````5`(``"R2__^Y`````$$.$(,"1PZP0`*C"@X000X(1`L0````>`(``,B2
M__\%`````````$P```",`@``Q)+___\!````0@X0C0)"#AB,`T$.((8$00XH
M@P52#M`A`F`*#BA!#B!!#AA"#A!"#@A""P*A#M@A2P[@(7(.V"%!#M`A````
M&````-P"``!TE/__(@````!!#A"#`EP."````"````#X`@``B)3__T0`````
M2PX0@P)8PPX(70X0@P)##@@``!@````<`P``M)3__S<!````1`X@`P@!"@X(
M1`L4````.`,``-B5__\X`````$0.(',."``8````4`,```"6__\D`````$0.
M$%@*#@A$"P``.````&P#```4EO__K0````!"#A",`D$.&(8#0PX@@P1,#C`"
M2`XX2PY`;0XX00XP50X@00X800X00@X(C````*@#``"(EO__G`8```!"#A".
M`D(.&(T#0@X@C`1!#BB&!40.,(,&3`Z``P/J`0Z(`T4.D`-X#H@#0@Z``P,!
M`0H.,$$.*$$.($(.&$(.$$(."$<+`V,!#H@#00Z0`VP.B`-!#H`#70Z(`TL.
MD`-!#I@#1`Z@`UL.@`,"V`Z(`T8.D`-@#H@#00Z``P``*````#@$``"8G/__
M5@(```!!#A"&`D$.&(,#1`XP`Y\!"@X800X000X(20LP````9`0``,R>__]>
M`````$$.$(8"00X8@P-'#B`"00H.&$$.$$$."$0+1`X81`X000X()````)@$
M``#(A/__]P$```!!#A"#`D0.0`.&`0H.$$,."$$+`````$@```#`!```T)[_
M_\$5````0@X0CP)"#AB.`T8.((T$0@XHC`5!#C"&!D$..(,'1P[(!`.A%0XX
M00XP00XH0@X@0@X80@X00@X(```4````#`4``%2T__]4`````$0.$`)/#@A@
M````)`4``)RT__^2`0```$(.$(\"0@X8C@-%#B"-!$(.*(P%1`XPA@9!#CB#
M!TH.0`)E"@XX00XP00XH0@X@0@X80@X00@X(1PL"P0H..$$.,$$.*$(.($(.
M&$(.$$(."$4+/````(@%``#8M?__(P(```!"#A".`D(.&(T#1@X@C`1!#BB&
M!40.,(,&`XH!"@XH00X@0@X80@X00@X(2`L``!````#(!0``UK?__PX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````!`B0```````X"%`````````````````````````
M```````````````!`````````+`"`````````0````````"[`@````````$`
M````````Q0(````````!`````````-,"````````'0````````!4!```````
M``P`````````4!M````````-`````````&Q30```````&0````````"0K4``
M`````!L`````````"``````````:`````````)BM0```````'``````````(
M``````````0`````````,`-```````#U_O]O`````+@%0```````!0``````
M``!P#T````````8`````````N`9````````*`````````(D$````````"P``
M```````8`````````!4````````````````````#`````````.BO0```````
M`@````````!P!0```````!0`````````!P`````````7`````````.`50```
M````!P`````````X%4````````@`````````J``````````)`````````!@`
M````````_O__;P````"X%$```````/___V\``````0````````#P__]O````
M`/H30```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````+BM0```````````````
M`````````````(8;0```````EAM```````"F&T```````+8;0```````QAM`
M``````#6&T```````.8;0```````]AM````````&'$```````!8<0```````
M)AQ````````V'$```````$8<0```````5AQ```````!F'$```````'8<0```
M````AAQ```````"6'$```````*8<0```````MAQ```````#&'$```````-8<
M0```````YAQ```````#V'$````````8=0```````%AU````````F'4``````
M`#8=0```````1AU```````!6'4```````&8=0```````=AU```````"&'4``
M`````)8=0```````IAU```````"V'4```````,8=0```````UAU```````#F
M'4```````/8=0```````!AY````````6'D```````"8>0```````-AY`````
M``!&'D```````%8>0```````9AY```````!V'D```````(8>0```````EAY`
M``````"F'D```````+8>0```````QAY```````#6'D```````.8>0```````
M]AY````````&'T```````!8?0`````````````````````````````I005(N
M<&T*``````````!05D```````%`A0```````4%-```````!'0T,Z("A355-%
M($QI;G5X*2`Q,RXS+C``1T-#.B`H4U5312!,:6YU>"D@-RXU+C```"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N
M<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O
M`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`7U]P871C:&%B;&5?9G5N
M8W1I;VY?96YT<FEE<P`N8G-S`"YC;VUM96YT````````````````````````
M````````````````````````````````````````````````````````````
M````````````"P````$````"`````````*@"0```````J`(````````<````
M`````````````````0```````````````````!,````'`````@````````#(
M`D```````,@"````````(`````````````````````@`````````````````
M```F````!P````(`````````Z`)```````#H`@```````"``````````````
M```````$````````````````````-`````<````"``````````@#0```````
M"`,````````D````````````````````!````````````````````$L````%
M`````@`````````P`T```````#`#````````B`(````````'``````````@`
M````````!`````````!'````]O__;P(`````````N`5```````"X!0``````
M```!````````!P`````````(````````````````````40````L````"````
M`````+@&0```````N`8```````"X"`````````@````!````"``````````8
M`````````%D````#`````@````````!P#T```````'`/````````B00`````
M``````````````$```````````````````!A````____;P(`````````^A-`
M``````#Z$P```````+H`````````!P`````````"``````````(`````````
M;@```/[__V\"`````````+@40```````N!0```````"```````````@````!
M````"````````````````````'T````$`````@`````````X%4```````#@5
M````````J``````````'``````````@`````````&`````````"'````!```
M`$(`````````X!5```````#@%0```````'`%````````!P```!D````(````
M`````!@`````````D0````$````&`````````%`;0```````4!L````````7
M````````````````````!````````````````````(P````!````!@``````
M``!P&T```````'`;````````L`,``````````````````!``````````$```
M``````"7`````0````8`````````(!]````````@'P```````$PT````````
M```````````0````````````````````G0````$````&`````````&Q30```
M````;%,````````)````````````````````!````````````````````*,`
M```!`````@````````!X4T```````'A3````````$D$`````````````````
M``@```````````````````"K`````0````(`````````C)1```````",E```
M``````0!```````````````````$````````````````````N0````$````"
M`````````)"50```````D)4````````(!@``````````````````"```````
M`````````````,,````.`````P````````"0K4```````)"=````````"```
M``````````````````@`````````"`````````#/````#P````,`````````
MF*U```````"8G0````````@````````````````````(``````````@`````
M````VP````$````#`````````*"M0```````H)T````````3````````````
M````````$````````````````````.@````&`````P````````"XK4``````
M`+B=````````(`(````````(``````````@`````````$`````````#Q````
M`0````,`````````V*]```````#8GP```````!`````````````````````(
M``````````@`````````]@````$````#`````````.BO0```````Z)\`````
M``#H`0``````````````````"``````````(`````````/\````!`````P``
M``````#0L4```````-"A````````*`````````````````````@`````````
M```````````%`0```0```(,`````````^+%```````#XH0```````!``````
M````#P`````````(````````````````````(@$```@````#`````````""R
M0```````"*(```````!H````````````````````(```````````````````
M`"<!```!````,`````````````````````BB````````,0``````````````
M``````$``````````0`````````!`````P`````````````````````````Y
GH@```````#`!```````````````````!````````````````````
